==> text-modes-1.73-pkg.tar.gz: lisp/text-modes/custom-load.el <==
;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'filladapt '("filladapt"))
(custom-add-loads 'apache '("auto-autoloads" "apache-mode"))
(custom-add-loads 'rtf '("rtf-support"))
(custom-add-loads 'xrdb '("xrdb-mode"))
(custom-add-loads 'ispell '("flyspell"))
(custom-add-loads 'tools '("autoinsert" "folding"))
(custom-add-loads 'hypermedia '("css-mode" "htmlize"))
(custom-add-loads 'desktop-entry '("desktop-entry-mode"))
(custom-add-loads 'css '("css-mode"))
(custom-add-loads 'outlines '("whitespace-mode"))
(custom-add-loads 'hexl '("hexl"))
(custom-add-loads 'data '("hexl"))
(custom-add-loads 'crontab '("crontab"))
(custom-add-loads 'ansi-colors '("ansi-color"))
(custom-add-loads 'scribe '("scribe"))
(custom-add-loads 'auto-insert '("autoinsert"))
(custom-add-loads 'htmlize '("htmlize"))
(custom-add-loads 'desktop-entry-faces '("desktop-entry-mode"))
(custom-add-loads 'flyspell '("flyspell"))
(custom-add-loads 'languages '("auto-autoloads" "crontab" "css-mode" "desktop-entry-mode" "winmgr-mode" "xrdb-mode"))
(custom-add-loads 'fill '("filladapt"))
(custom-add-loads 'folding '("folding"))
(custom-add-loads 'faces '("desktop-entry-mode"))
(custom-add-loads 'processes '("ansi-color" "flyspell"))
(custom-add-loads 'wp '("rtf-support" "scribe"))
(custom-add-loads 'po '("po-mode"))
(custom-add-loads 'whitespace '("whitespace-mode"))
(custom-add-loads 'matching '("whitespace-mode"))
(custom-add-loads 'winmgr '("winmgr-mode"))
(custom-add-loads 'i18n '("po-mode"))

;;; custom-load.el ends here

==> text-modes-1.82-pkg.tar.gz: lisp/text-modes/custom-load.el <==
;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'filladapt '("filladapt"))
(custom-add-loads 'apache '("auto-autoloads" "apache-mode"))
(custom-add-loads 'rtf '("rtf-support"))
(custom-add-loads 'convenience '("whitespace"))
(custom-add-loads 'xrdb '("xrdb-mode"))
(custom-add-loads 'ispell '("flyspell"))
(custom-add-loads 'tools '("autoinsert" "folding"))
(custom-add-loads 'hypermedia '("css-mode" "htmlize"))
(custom-add-loads 'desktop-entry '("desktop-entry-mode"))
(custom-add-loads 'css '("css-mode"))
(custom-add-loads 'outlines '("whitespace-mode"))
(custom-add-loads 'hexl '("hexl"))
(custom-add-loads 'old-whitespace '("whitespace-mode"))
(custom-add-loads 'data '("hexl"))
(custom-add-loads 'crontab '("crontab"))
(custom-add-loads 'ansi-colors '("ansi-color"))
(custom-add-loads 'scribe '("scribe"))
(custom-add-loads 'auto-insert '("autoinsert"))
(custom-add-loads 'htmlize '("htmlize"))
(custom-add-loads 'desktop-entry-faces '("desktop-entry-mode"))
(custom-add-loads 'flyspell '("flyspell"))
(custom-add-loads 'languages '("auto-autoloads" "crontab" "css-mode" "desktop-entry-mode" "winmgr-mode" "xrdb-mode"))
(custom-add-loads 'fill '("filladapt"))
(custom-add-loads 'folding '("folding"))
(custom-add-loads 'faces '("desktop-entry-mode" "whitespace"))
(custom-add-loads 'processes '("ansi-color" "flyspell"))
(custom-add-loads 'wp '("rtf-support" "scribe"))
(custom-add-loads 'po '("po-mode"))
(custom-add-loads 'whitespace-faces '("whitespace"))
(custom-add-loads 'whitespace '("whitespace"))
(custom-add-loads 'editing '("whitespace"))
(custom-add-loads 'matching '("whitespace-mode"))
(custom-add-loads 'winmgr '("winmgr-mode"))
(custom-add-loads 'i18n '("po-mode"))

;;; custom-load.el ends here
